from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.item_secure_note_type import ItemSecureNoteType
from ..types import UNSET, Unset

T = TypeVar("T", bound="ItemSecureNote")


@_attrs_define
class ItemSecureNote:
    """
    Attributes:
        type_ (Union[Unset, ItemSecureNoteType]):
    """

    type_: Union[Unset, ItemSecureNoteType] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        type_: Union[Unset, int] = UNSET
        if not isinstance(self.type_, Unset):
            type_ = self.type_.value

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if type_ is not UNSET:
            field_dict["type"] = type_

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        _type_ = d.pop("type", UNSET)
        type_: Union[Unset, ItemSecureNoteType]
        if isinstance(_type_, Unset):
            type_ = UNSET
        else:
            type_ = ItemSecureNoteType(_type_)

        item_secure_note = cls(
            type_=type_,
        )

        item_secure_note.additional_properties = d
        return item_secure_note

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
